@@ -1,4 +1,5 @@
 from os import system as run
+from sys import stdout
 from typing import List, Optional
 
 import typer
@@ -17,12 +18,20 @@ from compose_companion.functions import (
 )
 
 def autocomplete_containers(incomplete: str):
-    services = Configurations().services
-    completion = []
-    for name in services:
-        if name.startswith(incomplete):
-            completion.append(name)
-    return completion
+    try:
+        stdout_bak = stdout
+        stdout = False
+
+        completion = []
+        services = Configurations().services
+        for name in services:
+            if name.startswith(incomplete):
+                completion.append(name)
+
+        stdout = stdout_bak
+        return completion
+    except:
+        return []
 
 app = typer.Typer()
 err_console = Console(stderr=True)
